@@ -35,7 +35,7 @@ import java.util.*;
  * <code>HtmlPrinter</code>NX̋@\NXB
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/16 16:12:51 $
+ * @version $Revision: 1.3 $, $Date: 2007/06/25 16:07:41 $
  */
 public class HtmlPrinterTest extends FunctionTester
 {
@@ -185,6 +185,7 @@ public class HtmlPrinterTest extends FunctionTester
     oi.ignore("OPT_INDEX");
     oi.ignore("OPT_MESSAGE");
     oi.ignore("htmlRes_");
+    oi.expect("replacedMap_", new HashMap<String,Object>());
     oi.expect("isStopped_", false);
     oi.expect("coverage_", null);
     oi.expect("testerName_", "");
@@ -200,10 +201,17 @@ public class HtmlPrinterTest extends FunctionTester
 
   public void postCoverage()
   {
-    MSG("JobWv̌㏈̊mFiĂȂjB");
-    HtmlPrinter printer = new HtmlPrinter();
+    MSG("JobWv̌㏈̊mFB");
+
+    HtmlPrinter printer = new HtmlPrinter() {
+      @Override protected void outputHtmlFileForCoverage() {
+        OK();
+      }
+    };
     printer.postCoverage(null);
-    OK();
+
+    HtmlPrinter printer2 = new HtmlPrinter();
+    printer2.postCoverage(null);
   }
 
   public void entryLine()
@@ -247,6 +255,71 @@ public class HtmlPrinterTest extends FunctionTester
   }
 
   public void outputHtmlFile()
+  {
+    MSG("wqli[}bvݒ");
+
+    ObjectInspector oi = new ObjectInspector(this);
+    oi.ignore("KEY_COVERAGE_HEADER");
+    oi.ignore("KEY_COVERAGE_FOOTER");
+    oi.ignore("KEY_CLASS_COVERAGE_PREMETHODS");
+    oi.ignore("KEY_CLASS_COVERAGE_POSTMETHODS");
+    oi.ignore("KEY_METHOD_COVERAGE");
+    oi.ignore("FMT_SRC_COVERAGE");
+    oi.ignore("FMT_CLASS_COVERAGE");
+    oi.ignore("FMT_METHOD_COVERAGE");
+    oi.ignore("OPT_NAME");
+    oi.ignore("OPT_LASTNAME");
+    oi.ignore("OPT_PACKAGEDIR");
+    oi.ignore("OPT_INDEX");
+    oi.ignore("OPT_LINES");
+    oi.ignore("OPT_PASSED");
+    oi.ignore("OPT_UNPASSED");
+    oi.ignore("OPT_PASSED_RATIO");
+    oi.ignore("OPT_UNPASSED_RATIO");
+    oi.ignore("OPT_PASSED_LINES");
+    oi.ignore("OPT_UNPASSED_LINES");
+    oi.ignore("KEY_TOFILE");
+    oi.ignore("KEY_HEADER");
+    oi.ignore("KEY_PRECASES");
+    oi.ignore("KEY_CASE");
+    oi.ignore("KEY_POSTCASES");
+    oi.ignore("KEY_FOOTER");
+    oi.ignore("PREFIX_CHAR");
+    oi.ignore("EOL");
+    oi.ignore("FMT_TEST");
+    oi.ignore("FMT_CASE");
+    oi.ignore("OPT_NAME");
+    oi.ignore("OPT_TESTER");
+    oi.ignore("OPT_DATE");
+    oi.ignore("OPT_JUDGE");
+    oi.ignore("OPT_CHECK");
+    oi.ignore("OPT_GOOD");
+    oi.ignore("OPT_NOGOOD");
+    oi.ignore("OPT_KNOWNBUG");
+    oi.ignore("OPT_CHILD");
+    oi.ignore("OPT_EMPTY");
+    oi.ignore("OPT_INCOMPLETE");
+    oi.ignore("OPT_INDEX");
+    oi.ignore("OPT_MESSAGE");
+    oi.ignore("htmlRes_");
+    oi.expect("replacedMap_", new HashMap<String,Object>());
+    oi.expect("isStopped_", false);
+    oi.expect("coverage_", null);
+    oi.expect("testerName_", "");
+
+    HtmlPrinter printer = new HtmlPrinter();
+    oi.inspect(printer);
+
+    Map<String,Object> repMap = new HashMap<String,Object>();
+    repMap.put("aaa", "AAA");
+    repMap.put("bbb", "BBB");
+
+    printer.outputHtmlFile(repMap);
+    oi.expect("replacedMap_", repMap);
+    oi.inspect(printer);
+  }
+
+  public void outputHtmlFileForCoverage()
   {
     MSG("ʂHTMLt@Cɏo͂鏈̊mFB");
 
@@ -292,8 +365,8 @@ public class HtmlPrinterTest extends FunctionTester
       }
     };
     printer.prepareCoverage(coverage);
-
     printer.outputHtmlFile(objMap);
+    printer.postCoverage(coverage);
 
     try {
       File f = new File(PATH);
@@ -319,7 +392,7 @@ public class HtmlPrinterTest extends FunctionTester
     }
   }
 
-  public void outputHtmlFile_1()
+  public void outputHtmlFileForCoverage_1()
   {
     MSG("HTMLt@C̃pXsȏꍇB");
 
@@ -342,6 +415,7 @@ public class HtmlPrinterTest extends FunctionTester
     c0.addChildResult(c2);
 
     printer.outputHtmlFile(objMap);
+    printer.outputHtmlFileForCoverage();
 
     try {
       File f = new File(PATH);
